from setuptools import setup

setup(name='receptive',
      version='1.3',
      description='Receptive integration for Python',
      url='https://github.com/Receptive/receptive-python',
      author='Dan Dukeson',
      author_email='dan@receptive.io',
      license='MIT',
      packages=['receptive'],
      test_suite='nose.collector',
      tests_require=['nose'],
      zip_safe=False)




import hashlib

def extract_vals(d, accum):
    for key, value in d.iteritems():
        if isinstance(value, dict):
            extract_vals(value, accum)
        else:
            accum.append(value)                

def sign(unsigned, secret):
    vals = [secret]
    extract_vals(unsigned, vals)
    vals.sort()
    unsigned['signature'] = hashlib.sha256(','.join(vals)).hexdigest()
    return unsigned

